<a id="types-aiobotocore-medialive"></a>

# types-aiobotocore-medialive

[![PyPI - types-aiobotocore-medialive](https://img.shields.io/pypi/v/types-aiobotocore-medialive.svg?color=blue)](https://pypi.org/project/types-aiobotocore-medialive)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-medialive.svg?color=blue)](https://pypi.org/project/types-aiobotocore-medialive)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-medialive?color=blue)](https://pypistats.org/packages/types-aiobotocore-medialive)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.MediaLive 2.4.0](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/medialive.html#MediaLive)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.8](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-medialive docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_medialive/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-medialive](#types-aiobotocore-medialive)
  - [How to install](#how-to-install)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `MediaLive` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[medialive]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[medialive]'


# standalone installation
python -m pip install types-aiobotocore-medialive
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-medialive
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[medialive]` in your environment:

```bash
python -m pip install 'types-aiobotocore[medialive]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[medialive]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[medialive]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[medialive]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[medialive]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[medialive]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[medialive]` in your environment:

```bash
python -m pip install 'types-aiobotocore[medialive]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[medialive]` in your environment:

```bash
python -m pip install 'types-aiobotocore[medialive]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`MediaLiveClient` provides annotations for
`session.create_client("medialive")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_medialive import MediaLiveClient

session = get_session()
async with session.create_client("medialive") as client:
    client: MediaLiveClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_medialive.paginator` module contains type annotations for
all paginators.

```python
from aiobotocore.session import get_session

from types_aiobotocore_medialive import MediaLiveClient
from types_aiobotocore_medialive.paginator import (
    DescribeSchedulePaginator,
    ListChannelsPaginator,
    ListInputDeviceTransfersPaginator,
    ListInputDevicesPaginator,
    ListInputSecurityGroupsPaginator,
    ListInputsPaginator,
    ListMultiplexProgramsPaginator,
    ListMultiplexesPaginator,
    ListOfferingsPaginator,
    ListReservationsPaginator,
)

session = get_session()
async with session.create_client("medialive") as client:
    client: MediaLiveClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    describe_schedule_paginator: DescribeSchedulePaginator = client.get_paginator(
        "describe_schedule"
    )
    list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
    list_input_device_transfers_paginator: ListInputDeviceTransfersPaginator = client.get_paginator(
        "list_input_device_transfers"
    )
    list_input_devices_paginator: ListInputDevicesPaginator = client.get_paginator(
        "list_input_devices"
    )
    list_input_security_groups_paginator: ListInputSecurityGroupsPaginator = client.get_paginator(
        "list_input_security_groups"
    )
    list_inputs_paginator: ListInputsPaginator = client.get_paginator("list_inputs")
    list_multiplex_programs_paginator: ListMultiplexProgramsPaginator = client.get_paginator(
        "list_multiplex_programs"
    )
    list_multiplexes_paginator: ListMultiplexesPaginator = client.get_paginator("list_multiplexes")
    list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
    list_reservations_paginator: ListReservationsPaginator = client.get_paginator(
        "list_reservations"
    )
```

<a id="waiters-annotations"></a>

### Waiters annotations

`types_aiobotocore_medialive.waiter` module contains type annotations for all
waiters.

```python
from aiobotocore.session import get_session

from types_aiobotocore_medialive.client import MediaLiveClient
from types_aiobotocore_medialive.waiter import (
    ChannelCreatedWaiter,
    ChannelDeletedWaiter,
    ChannelRunningWaiter,
    ChannelStoppedWaiter,
    InputAttachedWaiter,
    InputDeletedWaiter,
    InputDetachedWaiter,
    MultiplexCreatedWaiter,
    MultiplexDeletedWaiter,
    MultiplexRunningWaiter,
    MultiplexStoppedWaiter,
)

session = get_session()
async with session.create_client("medialive") as client:
    client: MediaLiveClient

    # Explicit type annotations are optional here
    # Types should be correctly discovered by mypy and IDEs
    channel_created_waiter: ChannelCreatedWaiter = client.get_waiter("channel_created")
    channel_deleted_waiter: ChannelDeletedWaiter = client.get_waiter("channel_deleted")
    channel_running_waiter: ChannelRunningWaiter = client.get_waiter("channel_running")
    channel_stopped_waiter: ChannelStoppedWaiter = client.get_waiter("channel_stopped")
    input_attached_waiter: InputAttachedWaiter = client.get_waiter("input_attached")
    input_deleted_waiter: InputDeletedWaiter = client.get_waiter("input_deleted")
    input_detached_waiter: InputDetachedWaiter = client.get_waiter("input_detached")
    multiplex_created_waiter: MultiplexCreatedWaiter = client.get_waiter("multiplex_created")
    multiplex_deleted_waiter: MultiplexDeletedWaiter = client.get_waiter("multiplex_deleted")
    multiplex_running_waiter: MultiplexRunningWaiter = client.get_waiter("multiplex_running")
    multiplex_stopped_waiter: MultiplexStoppedWaiter = client.get_waiter("multiplex_stopped")
```

<a id="literals"></a>

### Literals

`types_aiobotocore_medialive.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_medialive.literals import (
    AacCodingModeType,
    AacInputTypeType,
    AacProfileType,
    AacRateControlModeType,
    AacRawFormatType,
    AacSpecType,
    AacVbrQualityType,
    Ac3BitstreamModeType,
    Ac3CodingModeType,
    Ac3DrcProfileType,
    Ac3LfeFilterType,
    Ac3MetadataControlType,
    AcceptHeaderType,
    AccessibilityTypeType,
    AfdSignalingType,
    AudioDescriptionAudioTypeControlType,
    AudioDescriptionLanguageCodeControlType,
    AudioLanguageSelectionPolicyType,
    AudioNormalizationAlgorithmControlType,
    AudioNormalizationAlgorithmType,
    AudioOnlyHlsSegmentTypeType,
    AudioOnlyHlsTrackTypeType,
    AudioTypeType,
    AuthenticationSchemeType,
    AvailBlankingStateType,
    BlackoutSlateNetworkEndBlackoutType,
    BlackoutSlateStateType,
    BurnInAlignmentType,
    BurnInBackgroundColorType,
    BurnInFontColorType,
    BurnInOutlineColorType,
    BurnInShadowColorType,
    BurnInTeletextGridControlType,
    CdiInputResolutionType,
    ChannelClassType,
    ChannelCreatedWaiterName,
    ChannelDeletedWaiterName,
    ChannelRunningWaiterName,
    ChannelStateType,
    ChannelStoppedWaiterName,
    ContentTypeType,
    DescribeSchedulePaginatorName,
    DeviceSettingsSyncStateType,
    DeviceUpdateStatusType,
    DvbSdtOutputSdtType,
    DvbSubDestinationAlignmentType,
    DvbSubDestinationBackgroundColorType,
    DvbSubDestinationFontColorType,
    DvbSubDestinationOutlineColorType,
    DvbSubDestinationShadowColorType,
    DvbSubDestinationTeletextGridControlType,
    DvbSubOcrLanguageType,
    Eac3AttenuationControlType,
    Eac3BitstreamModeType,
    Eac3CodingModeType,
    Eac3DcFilterType,
    Eac3DrcLineType,
    Eac3DrcRfType,
    Eac3LfeControlType,
    Eac3LfeFilterType,
    Eac3MetadataControlType,
    Eac3PassthroughControlType,
    Eac3PhaseControlType,
    Eac3StereoDownmixType,
    Eac3SurroundExModeType,
    Eac3SurroundModeType,
    EbuTtDDestinationStyleControlType,
    EbuTtDFillLineGapControlType,
    EmbeddedConvert608To708Type,
    EmbeddedScte20DetectionType,
    FeatureActivationsInputPrepareScheduleActionsType,
    FecOutputIncludeFecType,
    FixedAfdType,
    Fmp4NielsenId3BehaviorType,
    Fmp4TimedMetadataBehaviorType,
    FollowPointType,
    FrameCaptureIntervalUnitType,
    GlobalConfigurationInputEndActionType,
    GlobalConfigurationLowFramerateInputsType,
    GlobalConfigurationOutputLockingModeType,
    GlobalConfigurationOutputTimingSourceType,
    H264AdaptiveQuantizationType,
    H264ColorMetadataType,
    H264EntropyEncodingType,
    H264FlickerAqType,
    H264ForceFieldPicturesType,
    H264FramerateControlType,
    H264GopBReferenceType,
    H264GopSizeUnitsType,
    H264LevelType,
    H264LookAheadRateControlType,
    H264ParControlType,
    H264ProfileType,
    H264QualityLevelType,
    H264RateControlModeType,
    H264ScanTypeType,
    H264SceneChangeDetectType,
    H264SpatialAqType,
    H264SubGopLengthType,
    H264SyntaxType,
    H264TemporalAqType,
    H264TimecodeInsertionBehaviorType,
    H265AdaptiveQuantizationType,
    H265AlternativeTransferFunctionType,
    H265ColorMetadataType,
    H265FlickerAqType,
    H265GopSizeUnitsType,
    H265LevelType,
    H265LookAheadRateControlType,
    H265ProfileType,
    H265RateControlModeType,
    H265ScanTypeType,
    H265SceneChangeDetectType,
    H265TierType,
    H265TimecodeInsertionBehaviorType,
    HlsAdMarkersType,
    HlsAkamaiHttpTransferModeType,
    HlsCaptionLanguageSettingType,
    HlsClientCacheType,
    HlsCodecSpecificationType,
    HlsDirectoryStructureType,
    HlsDiscontinuityTagsType,
    HlsEncryptionTypeType,
    HlsH265PackagingTypeType,
    HlsId3SegmentTaggingStateType,
    HlsIncompleteSegmentBehaviorType,
    HlsIvInManifestType,
    HlsIvSourceType,
    HlsManifestCompressionType,
    HlsManifestDurationFormatType,
    HlsMediaStoreStorageClassType,
    HlsModeType,
    HlsOutputSelectionType,
    HlsProgramDateTimeClockType,
    HlsProgramDateTimeType,
    HlsRedundantManifestType,
    HlsScte35SourceTypeType,
    HlsSegmentationModeType,
    HlsStreamInfResolutionType,
    HlsTimedMetadataId3FrameType,
    HlsTsFileModeType,
    HlsWebdavHttpTransferModeType,
    IFrameOnlyPlaylistTypeType,
    InputAttachedWaiterName,
    InputClassType,
    InputCodecType,
    InputDeblockFilterType,
    InputDeletedWaiterName,
    InputDenoiseFilterType,
    InputDetachedWaiterName,
    InputDeviceActiveInputType,
    InputDeviceConfiguredInputType,
    InputDeviceConnectionStateType,
    InputDeviceIpSchemeType,
    InputDeviceScanTypeType,
    InputDeviceStateType,
    InputDeviceTransferTypeType,
    InputDeviceTypeType,
    InputFilterType,
    InputLossActionForHlsOutType,
    InputLossActionForMsSmoothOutType,
    InputLossActionForRtmpOutType,
    InputLossActionForUdpOutType,
    InputLossImageTypeType,
    InputMaximumBitrateType,
    InputPreferenceType,
    InputResolutionType,
    InputSecurityGroupStateType,
    InputSourceEndBehaviorType,
    InputSourceTypeType,
    InputStateType,
    InputTimecodeSourceType,
    InputTypeType,
    LastFrameClippingBehaviorType,
    ListChannelsPaginatorName,
    ListInputDeviceTransfersPaginatorName,
    ListInputDevicesPaginatorName,
    ListInputSecurityGroupsPaginatorName,
    ListInputsPaginatorName,
    ListMultiplexProgramsPaginatorName,
    ListMultiplexesPaginatorName,
    ListOfferingsPaginatorName,
    ListReservationsPaginatorName,
    LogLevelType,
    M2tsAbsentInputAudioBehaviorType,
    M2tsAribCaptionsPidControlType,
    M2tsAribType,
    M2tsAudioBufferModelType,
    M2tsAudioIntervalType,
    M2tsAudioStreamTypeType,
    M2tsBufferModelType,
    M2tsCcDescriptorType,
    M2tsEbifControlType,
    M2tsEbpPlacementType,
    M2tsEsRateInPesType,
    M2tsKlvType,
    M2tsNielsenId3BehaviorType,
    M2tsPcrControlType,
    M2tsRateModeType,
    M2tsScte35ControlType,
    M2tsSegmentationMarkersType,
    M2tsSegmentationStyleType,
    M2tsTimedMetadataBehaviorType,
    M3u8NielsenId3BehaviorType,
    M3u8PcrControlType,
    M3u8Scte35BehaviorType,
    M3u8TimedMetadataBehaviorType,
    MaintenanceDayType,
    MotionGraphicsInsertionType,
    Mp2CodingModeType,
    Mpeg2AdaptiveQuantizationType,
    Mpeg2ColorMetadataType,
    Mpeg2ColorSpaceType,
    Mpeg2DisplayRatioType,
    Mpeg2GopSizeUnitsType,
    Mpeg2ScanTypeType,
    Mpeg2SubGopLengthType,
    Mpeg2TimecodeInsertionBehaviorType,
    MsSmoothH265PackagingTypeType,
    MultiplexCreatedWaiterName,
    MultiplexDeletedWaiterName,
    MultiplexRunningWaiterName,
    MultiplexStateType,
    MultiplexStoppedWaiterName,
    NetworkInputServerValidationType,
    NielsenPcmToId3TaggingStateType,
    NielsenWatermarksCbetStepasideType,
    NielsenWatermarksDistributionTypesType,
    OfferingDurationUnitsType,
    OfferingTypeType,
    PipelineIdType,
    PreferredChannelPipelineType,
    RebootInputDeviceForceType,
    ReservationAutomaticRenewalType,
    ReservationCodecType,
    ReservationMaximumBitrateType,
    ReservationMaximumFramerateType,
    ReservationResolutionType,
    ReservationResourceTypeType,
    ReservationSpecialFeatureType,
    ReservationStateType,
    ReservationVideoQualityType,
    RtmpAdMarkersType,
    RtmpCacheFullBehaviorType,
    RtmpCaptionDataType,
    RtmpOutputCertificateModeType,
    S3CannedAclType,
    Scte20Convert608To708Type,
    Scte27OcrLanguageType,
    Scte35AposNoRegionalBlackoutBehaviorType,
    Scte35AposWebDeliveryAllowedBehaviorType,
    Scte35ArchiveAllowedFlagType,
    Scte35DeviceRestrictionsType,
    Scte35NoRegionalBlackoutFlagType,
    Scte35SegmentationCancelIndicatorType,
    Scte35SpliceInsertNoRegionalBlackoutBehaviorType,
    Scte35SpliceInsertWebDeliveryAllowedBehaviorType,
    Scte35WebDeliveryAllowedFlagType,
    SmoothGroupAudioOnlyTimecodeControlType,
    SmoothGroupCertificateModeType,
    SmoothGroupEventIdModeType,
    SmoothGroupEventStopBehaviorType,
    SmoothGroupSegmentationModeType,
    SmoothGroupSparseTrackTypeType,
    SmoothGroupStreamManifestBehaviorType,
    SmoothGroupTimestampOffsetModeType,
    Smpte2038DataPreferenceType,
    TemporalFilterPostFilterSharpeningType,
    TemporalFilterStrengthType,
    TimecodeConfigSourceType,
    TtmlDestinationStyleControlType,
    UdpTimedMetadataId3FrameType,
    VideoDescriptionRespondToAfdType,
    VideoDescriptionScalingBehaviorType,
    VideoSelectorColorSpaceType,
    VideoSelectorColorSpaceUsageType,
    WavCodingModeType,
    WebvttDestinationStyleControlType,
    MediaLiveServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    WaiterName,
    RegionName,
)


def check_value(value: AacCodingModeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_medialive.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_medialive.type_defs import (
    AacSettingsTypeDef,
    Ac3SettingsTypeDef,
    AcceptInputDeviceTransferRequestRequestTypeDef,
    AncillarySourceSettingsTypeDef,
    ArchiveS3SettingsTypeDef,
    OutputLocationRefTypeDef,
    InputChannelLevelTypeDef,
    Eac3SettingsTypeDef,
    Mp2SettingsTypeDef,
    WavSettingsTypeDef,
    AudioNormalizationSettingsTypeDef,
    AudioHlsRenditionSelectionTypeDef,
    AudioLanguageSelectionTypeDef,
    InputLocationTypeDef,
    AudioPidSelectionTypeDef,
    AudioSilenceFailoverSettingsTypeDef,
    AudioTrackTypeDef,
    Scte35SpliceInsertTypeDef,
    Scte35TimeSignalAposTypeDef,
    BatchDeleteRequestRequestTypeDef,
    BatchFailedResultModelTypeDef,
    BatchSuccessfulResultModelTypeDef,
    ResponseMetadataTypeDef,
    BatchScheduleActionDeleteRequestTypeDef,
    BatchStartRequestRequestTypeDef,
    BatchStopRequestRequestTypeDef,
    CancelInputDeviceTransferRequestRequestTypeDef,
    EbuTtDDestinationSettingsTypeDef,
    TtmlDestinationSettingsTypeDef,
    WebvttDestinationSettingsTypeDef,
    CaptionLanguageMappingTypeDef,
    CaptionRectangleTypeDef,
    DvbSubSourceSettingsTypeDef,
    EmbeddedSourceSettingsTypeDef,
    Scte20SourceSettingsTypeDef,
    Scte27SourceSettingsTypeDef,
    CdiInputSpecificationTypeDef,
    ChannelEgressEndpointTypeDef,
    InputSpecificationTypeDef,
    MaintenanceStatusTypeDef,
    VpcOutputSettingsDescriptionTypeDef,
    PipelineDetailTypeDef,
    ClaimDeviceRequestRequestTypeDef,
    MaintenanceCreateSettingsTypeDef,
    VpcOutputSettingsTypeDef,
    InputDestinationRequestTypeDef,
    InputDeviceSettingsTypeDef,
    InputSourceRequestTypeDef,
    InputVpcRequestTypeDef,
    MediaConnectFlowRequestTypeDef,
    InputWhitelistRuleCidrTypeDef,
    MultiplexSettingsTypeDef,
    CreatePartnerInputRequestRequestTypeDef,
    CreateTagsRequestRequestTypeDef,
    DeleteChannelRequestRequestTypeDef,
    DeleteInputRequestRequestTypeDef,
    DeleteInputSecurityGroupRequestRequestTypeDef,
    DeleteMultiplexProgramRequestRequestTypeDef,
    MultiplexProgramPacketIdentifiersMapTypeDef,
    MultiplexProgramPipelineDetailTypeDef,
    DeleteMultiplexRequestRequestTypeDef,
    DeleteReservationRequestRequestTypeDef,
    RenewalSettingsTypeDef,
    ReservationResourceSpecificationTypeDef,
    DeleteScheduleRequestRequestTypeDef,
    DeleteTagsRequestRequestTypeDef,
    WaiterConfigTypeDef,
    DescribeChannelRequestRequestTypeDef,
    DescribeInputDeviceRequestRequestTypeDef,
    InputDeviceHdSettingsTypeDef,
    InputDeviceNetworkSettingsTypeDef,
    InputDeviceUhdSettingsTypeDef,
    DescribeInputDeviceThumbnailRequestRequestTypeDef,
    DescribeInputRequestRequestTypeDef,
    InputSourceTypeDef,
    MediaConnectFlowTypeDef,
    DescribeInputSecurityGroupRequestRequestTypeDef,
    InputWhitelistRuleTypeDef,
    DescribeMultiplexProgramRequestRequestTypeDef,
    DescribeMultiplexRequestRequestTypeDef,
    DescribeOfferingRequestRequestTypeDef,
    DescribeReservationRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    DescribeScheduleRequestRequestTypeDef,
    DvbNitSettingsTypeDef,
    DvbSdtSettingsTypeDef,
    DvbTdtSettingsTypeDef,
    FeatureActivationsTypeDef,
    NielsenConfigurationTypeDef,
    TimecodeConfigTypeDef,
    InputLossFailoverSettingsTypeDef,
    VideoBlackFailoverSettingsTypeDef,
    FecOutputSettingsTypeDef,
    FixedModeScheduleActionStartSettingsTypeDef,
    Fmp4HlsSettingsTypeDef,
    FollowModeScheduleActionStartSettingsTypeDef,
    FrameCaptureS3SettingsTypeDef,
    FrameCaptureOutputSettingsTypeDef,
    FrameCaptureSettingsTypeDef,
    H264ColorSpaceSettingsTypeDef,
    TemporalFilterSettingsTypeDef,
    Hdr10SettingsTypeDef,
    HlsAkamaiSettingsTypeDef,
    HlsBasicPutSettingsTypeDef,
    HlsMediaStoreSettingsTypeDef,
    HlsS3SettingsTypeDef,
    HlsWebdavSettingsTypeDef,
    HlsId3SegmentTaggingScheduleActionSettingsTypeDef,
    HlsInputSettingsTypeDef,
    HlsTimedMetadataScheduleActionSettingsTypeDef,
    StartTimecodeTypeDef,
    StopTimecodeTypeDef,
    InputDestinationVpcTypeDef,
    InputDeviceConfigurableSettingsTypeDef,
    InputDeviceRequestTypeDef,
    ListChannelsRequestRequestTypeDef,
    ListInputDeviceTransfersRequestRequestTypeDef,
    TransferringInputDeviceSummaryTypeDef,
    ListInputDevicesRequestRequestTypeDef,
    ListInputSecurityGroupsRequestRequestTypeDef,
    ListInputsRequestRequestTypeDef,
    ListMultiplexProgramsRequestRequestTypeDef,
    MultiplexProgramSummaryTypeDef,
    ListMultiplexesRequestRequestTypeDef,
    ListOfferingsRequestRequestTypeDef,
    ListReservationsRequestRequestTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    M3u8SettingsTypeDef,
    MaintenanceUpdateSettingsTypeDef,
    MediaPackageOutputDestinationSettingsTypeDef,
    MotionGraphicsActivateScheduleActionSettingsTypeDef,
    MotionGraphicsSettingsTypeDef,
    MsSmoothOutputSettingsTypeDef,
    MultiplexMediaConnectOutputDestinationSettingsTypeDef,
    MultiplexProgramChannelDestinationSettingsTypeDef,
    MultiplexProgramServiceDescriptorTypeDef,
    MultiplexSettingsSummaryTypeDef,
    MultiplexStatmuxVideoSettingsTypeDef,
    NielsenCBETTypeDef,
    NielsenNaesIiNwTypeDef,
    OutputDestinationSettingsTypeDef,
    RtmpGroupSettingsTypeDef,
    UdpGroupSettingsTypeDef,
    PipelinePauseStateSettingsTypeDef,
    RebootInputDeviceRequestRequestTypeDef,
    RejectInputDeviceTransferRequestRequestTypeDef,
    Scte35ReturnToNetworkScheduleActionSettingsTypeDef,
    Scte35SpliceInsertScheduleActionSettingsTypeDef,
    StaticImageDeactivateScheduleActionSettingsTypeDef,
    Scte35DeliveryRestrictionsTypeDef,
    StartChannelRequestRequestTypeDef,
    StartInputDeviceMaintenanceWindowRequestRequestTypeDef,
    StartMultiplexRequestRequestTypeDef,
    StopChannelRequestRequestTypeDef,
    StopMultiplexRequestRequestTypeDef,
    TransferInputDeviceRequestRequestTypeDef,
    VideoSelectorPidTypeDef,
    VideoSelectorProgramIdTypeDef,
    ArchiveCdnSettingsTypeDef,
    MediaPackageGroupSettingsTypeDef,
    MsSmoothGroupSettingsTypeDef,
    MultiplexOutputSettingsTypeDef,
    RtmpOutputSettingsTypeDef,
    AudioChannelMappingTypeDef,
    AudioCodecSettingsTypeDef,
    AudioOnlyHlsSettingsTypeDef,
    AvailBlankingTypeDef,
    BlackoutSlateTypeDef,
    BurnInDestinationSettingsTypeDef,
    DvbSubDestinationSettingsTypeDef,
    InputLossBehaviorTypeDef,
    StaticImageActivateScheduleActionSettingsTypeDef,
    StaticKeySettingsTypeDef,
    AudioTrackSelectionTypeDef,
    AvailSettingsTypeDef,
    BatchDeleteResponseTypeDef,
    BatchStartResponseTypeDef,
    BatchStopResponseTypeDef,
    DescribeInputDeviceThumbnailResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    ListTagsForResourceResponseTypeDef,
    TeletextSourceSettingsTypeDef,
    CreateInputRequestRequestTypeDef,
    CreateInputSecurityGroupRequestRequestTypeDef,
    UpdateInputSecurityGroupRequestRequestTypeDef,
    CreateMultiplexRequestRequestTypeDef,
    UpdateMultiplexRequestRequestTypeDef,
    PurchaseOfferingRequestRequestTypeDef,
    UpdateReservationRequestRequestTypeDef,
    DeleteReservationResponseTypeDef,
    DescribeOfferingResponseTypeDef,
    DescribeReservationResponseTypeDef,
    OfferingTypeDef,
    ReservationTypeDef,
    DescribeChannelRequestChannelCreatedWaitTypeDef,
    DescribeChannelRequestChannelDeletedWaitTypeDef,
    DescribeChannelRequestChannelRunningWaitTypeDef,
    DescribeChannelRequestChannelStoppedWaitTypeDef,
    DescribeInputRequestInputAttachedWaitTypeDef,
    DescribeInputRequestInputDeletedWaitTypeDef,
    DescribeInputRequestInputDetachedWaitTypeDef,
    DescribeMultiplexRequestMultiplexCreatedWaitTypeDef,
    DescribeMultiplexRequestMultiplexDeletedWaitTypeDef,
    DescribeMultiplexRequestMultiplexRunningWaitTypeDef,
    DescribeMultiplexRequestMultiplexStoppedWaitTypeDef,
    DescribeInputDeviceResponseTypeDef,
    InputDeviceSummaryTypeDef,
    UpdateInputDeviceResponseTypeDef,
    DescribeInputSecurityGroupResponseTypeDef,
    InputSecurityGroupTypeDef,
    DescribeScheduleRequestDescribeSchedulePaginateTypeDef,
    ListChannelsRequestListChannelsPaginateTypeDef,
    ListInputDeviceTransfersRequestListInputDeviceTransfersPaginateTypeDef,
    ListInputDevicesRequestListInputDevicesPaginateTypeDef,
    ListInputSecurityGroupsRequestListInputSecurityGroupsPaginateTypeDef,
    ListInputsRequestListInputsPaginateTypeDef,
    ListMultiplexProgramsRequestListMultiplexProgramsPaginateTypeDef,
    ListMultiplexesRequestListMultiplexesPaginateTypeDef,
    ListOfferingsRequestListOfferingsPaginateTypeDef,
    ListReservationsRequestListReservationsPaginateTypeDef,
    M2tsSettingsTypeDef,
    FailoverConditionSettingsTypeDef,
    ScheduleActionStartSettingsTypeDef,
    FrameCaptureCdnSettingsTypeDef,
    H264FilterSettingsTypeDef,
    H265FilterSettingsTypeDef,
    Mpeg2FilterSettingsTypeDef,
    H265ColorSpaceSettingsTypeDef,
    VideoSelectorColorSpaceSettingsTypeDef,
    HlsCdnSettingsTypeDef,
    NetworkInputSettingsTypeDef,
    InputClippingSettingsTypeDef,
    InputDestinationTypeDef,
    UpdateInputDeviceRequestRequestTypeDef,
    UpdateInputRequestRequestTypeDef,
    ListInputDeviceTransfersResponseTypeDef,
    ListMultiplexProgramsResponseTypeDef,
    StandardHlsSettingsTypeDef,
    MotionGraphicsConfigurationTypeDef,
    MultiplexOutputDestinationTypeDef,
    MultiplexSummaryTypeDef,
    MultiplexVideoSettingsTypeDef,
    NielsenWatermarksSettingsTypeDef,
    OutputDestinationTypeDef,
    PauseStateScheduleActionSettingsTypeDef,
    Scte35SegmentationDescriptorTypeDef,
    VideoSelectorSettingsTypeDef,
    ArchiveGroupSettingsTypeDef,
    RemixSettingsTypeDef,
    CaptionDestinationSettingsTypeDef,
    GlobalConfigurationTypeDef,
    KeyProviderSettingsTypeDef,
    AudioSelectorSettingsTypeDef,
    AvailConfigurationTypeDef,
    CaptionSelectorSettingsTypeDef,
    ListOfferingsResponseTypeDef,
    ListReservationsResponseTypeDef,
    PurchaseOfferingResponseTypeDef,
    UpdateReservationResponseTypeDef,
    ListInputDevicesResponseTypeDef,
    CreateInputSecurityGroupResponseTypeDef,
    ListInputSecurityGroupsResponseTypeDef,
    UpdateInputSecurityGroupResponseTypeDef,
    ArchiveContainerSettingsTypeDef,
    UdpContainerSettingsTypeDef,
    FailoverConditionTypeDef,
    FrameCaptureGroupSettingsTypeDef,
    H264SettingsTypeDef,
    Mpeg2SettingsTypeDef,
    H265SettingsTypeDef,
    InputPrepareScheduleActionSettingsTypeDef,
    InputSwitchScheduleActionSettingsTypeDef,
    DescribeInputResponseTypeDef,
    InputTypeDef,
    HlsSettingsTypeDef,
    DeleteMultiplexResponseTypeDef,
    DescribeMultiplexResponseTypeDef,
    MultiplexTypeDef,
    StartMultiplexResponseTypeDef,
    StopMultiplexResponseTypeDef,
    ListMultiplexesResponseTypeDef,
    MultiplexProgramSettingsTypeDef,
    AudioWatermarkSettingsTypeDef,
    UpdateChannelClassRequestRequestTypeDef,
    Scte35DescriptorSettingsTypeDef,
    VideoSelectorTypeDef,
    CaptionDescriptionTypeDef,
    HlsGroupSettingsTypeDef,
    AudioSelectorTypeDef,
    CaptionSelectorTypeDef,
    ArchiveOutputSettingsTypeDef,
    UdpOutputSettingsTypeDef,
    AutomaticInputFailoverSettingsTypeDef,
    VideoCodecSettingsTypeDef,
    CreateInputResponseTypeDef,
    CreatePartnerInputResponseTypeDef,
    ListInputsResponseTypeDef,
    UpdateInputResponseTypeDef,
    HlsOutputSettingsTypeDef,
    CreateMultiplexResponseTypeDef,
    UpdateMultiplexResponseTypeDef,
    CreateMultiplexProgramRequestRequestTypeDef,
    DeleteMultiplexProgramResponseTypeDef,
    DescribeMultiplexProgramResponseTypeDef,
    MultiplexProgramTypeDef,
    UpdateMultiplexProgramRequestRequestTypeDef,
    AudioDescriptionTypeDef,
    Scte35DescriptorTypeDef,
    OutputGroupSettingsTypeDef,
    InputSettingsTypeDef,
    VideoDescriptionTypeDef,
    OutputSettingsTypeDef,
    CreateMultiplexProgramResponseTypeDef,
    UpdateMultiplexProgramResponseTypeDef,
    Scte35TimeSignalScheduleActionSettingsTypeDef,
    InputAttachmentTypeDef,
    OutputTypeDef,
    ScheduleActionSettingsTypeDef,
    ChannelSummaryTypeDef,
    OutputGroupTypeDef,
    ScheduleActionTypeDef,
    ListChannelsResponseTypeDef,
    EncoderSettingsTypeDef,
    BatchScheduleActionCreateRequestTypeDef,
    BatchScheduleActionCreateResultTypeDef,
    BatchScheduleActionDeleteResultTypeDef,
    DescribeScheduleResponseTypeDef,
    ChannelTypeDef,
    CreateChannelRequestRequestTypeDef,
    DeleteChannelResponseTypeDef,
    DescribeChannelResponseTypeDef,
    StartChannelResponseTypeDef,
    StopChannelResponseTypeDef,
    UpdateChannelRequestRequestTypeDef,
    BatchUpdateScheduleRequestRequestTypeDef,
    BatchUpdateScheduleResponseTypeDef,
    CreateChannelResponseTypeDef,
    UpdateChannelClassResponseTypeDef,
    UpdateChannelResponseTypeDef,
)


def get_structure() -> AacSettingsTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`types-aiobotocore-medialive` version is the same as related `aiobotocore`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_medialive/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
